pub enum PacketFrameError {
Header(PacketHeaderError),
InvalidMaxPacketSize(usize),
MismatchedPacketType {
expected: PacketType,
actual: PacketType,
},
UnexpectedPacketId {
expected: u8,
actual: u8,
},
MessageTooLarge,
}Expand description
Error returned while framing or deframing TDS packets.
Variants
Header(PacketHeaderError)
Packet header decoding failed.
InvalidMaxPacketSize(usize)
The requested packet size cannot be encoded in a TDS packet header or leaves no room for payload bytes.
MismatchedPacketType
A decoded message contained packets with different packet types.
Fields

expected: PacketTypePacket type from the first packet.

actual: PacketTypePacket type from a later packet in the same message.
UnexpectedPacketId
Packet IDs in a multi-packet message were not contiguous.
MessageTooLarge
The message could not fit in memory or in a protocol length field.