TokenParseError

Enum TokenParseError 

pub enum TokenParseError {
    UnexpectedEof,
    LengthOverflow,
    InvalidUtf16,
    UnsupportedToken(u8),
    TrailingTokenBytes(usize),
    MissingLoginAck,
    MissingDone,
    InvalidEnvChangePacketSize(String),
}
Error returned while parsing a bounded TDS token stream.

Variants



UnexpectedEof

The token stream ended in the middle of a token.



LengthOverflow

A token advertised a length that cannot be represented safely.



InvalidUtf16

A token contained invalid UTF-16 string data.



UnsupportedToken(u8)

This bounded parser does not yet understand the token type.



TrailingTokenBytes(usize)

A length-prefixed token contained extra bytes after its expected fields.



MissingLoginAck

A LOGIN7 response did not include LOGINACK.



MissingDone

A LOGIN7 response did not include DONE.



InvalidEnvChangePacketSize(String)

ENVCHANGE packet size was not a decimal integer.